OiRA

Help

1. It-Tħejjija
2. Involvi
3. L-Identifikazzjoni + Il-Valutazzjoni
4. Il-Pjan ta' Azzjoni
5. Ir-Rapport
6. Stat 0%

# Rappurtar

Issa li lestejt tidentifika r-riskji kollha fl-organizzazzjoni tiegħek u ħloqt pjan ta' azzjoni, tista' toħloq rapport li jelenka r-riżultati kollha tiegħek. Jekk tixtieq, tista' żżid kummenti addizzjonali li għandhom jiġu inklużi f'dan ir-rapport fil-qasam ta' hawn taħt.

Issejvja u kompli

Scroll to top
Back

## report.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More